@@ -1,16 +1,14 @@
 #' @importFrom V8 new_context
 ct <- NULL
 ext <- NULL
+topo <- NULL
 .onLoad <- function(libname, pkgname){
-  ct <<- new_context();
+  ct <<- V8::v8()
   ct$source(system.file("js/geojsonhint.js", package = pkgname))
   
-  ext <<- new_context();
+  ext <<- V8::v8()
   ext$source(system.file("js/turf_extent.js", package = pkgname))
+  
+  topo <<- V8::v8()
+  topo$source("https://unpkg.com/topojson-server@3")
 }
-
-# buf <- NULL
-# .onLoad <- function(libname, pkgname){
-#   buf <<- new_context();
-#   buf$source(system.file("js/geobuf.js", package = pkgname))
-# }
